============
lcep-package
============

.. image:: https://github.com/mlf-core/lcep-package/workflows/Build%20lcep-package%20Package/badge.svg
        :target: https://github.com/mlf-core/lcep-package/workflows/Build%20lcep-package%20Package/badge.svg
        :alt: Github Workflow Build lcep-package Status

.. image:: https://github.com/mlf-core/lcep-package/workflows/Run%20lcep-package%20Tox%20Test%20Suite/badge.svg
        :target: https://github.com/mlf-core/lcep-package/workflows/Run%20lcep-package%20Tox%20Test%20Suite/badge.svg
        :alt: Github Workflow Tests Status

.. image:: https://img.shields.io/pypi/v/lcep-package.svg
        :target: https://pypi.python.org/pypi/lcep-package
        :alt: PyPI Status


.. image:: https://readthedocs.org/projects/lcep-package/badge/?version=latest
        :target: https://lcep-package.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://flat.badgen.net/dependabot/thepracticaldev/dev.to?icon=dependabot
        :target: https://flat.badgen.net/dependabot/thepracticaldev/dev.to?icon=dependabot
        :alt: Dependabot Enabled


Python package for lcep.


* Free software: MIT
* Documentation: https://lcep-package.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with cookietemple_ using Cookiecutter_.

.. _cookietemple: https://cookietemple.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
